==> haskell-hspec-discover-2.5.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-discover
version: 2.5.2
id: hspec-discover-2.5.2-23fLrrXfs5EFsBWedVBtJb
key: hspec-discover-2.5.2-23fLrrXfs5EFsBWedVBtJb
license: MIT
copyright: (c) 2012-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests
    .
    <http://hspec.github.io/hspec-discover.html>
category: Testing
abi: c2926e4c977d616bb0d5ff255350c634
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort
hidden-modules: Paths_hspec_discover
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-discover-2.5.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-discover-2.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hspec-discover-2.5.2
hs-libraries: HShspec-discover-2.5.2-23fLrrXfs5EFsBWedVBtJb
depends:
    base-4.11.1.0 directory-1.3.1.5 filepath-1.4.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
haddock-interfaces: /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock
haddock-html: /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-discover-2.5.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-discover
version: 2.5.3
id: hspec-discover-2.5.3-G05uPpwzRat3ip08cQddLt
key: hspec-discover-2.5.3-G05uPpwzRat3ip08cQddLt
license: MIT
copyright: (c) 2012-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests
    .
    <http://hspec.github.io/hspec-discover.html>
category: Testing
abi: ab556713fb55ecb15b65aa9c1c7fbcde
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort
hidden-modules: Paths_hspec_discover
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-discover-2.5.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-discover-2.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hspec-discover-2.5.3
hs-libraries: HShspec-discover-2.5.3-G05uPpwzRat3ip08cQddLt
depends:
    base-4.11.1.0 directory-1.3.1.5 filepath-1.4.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
haddock-interfaces: /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock
haddock-html: /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
